#!/usr/bin/env bash

# Script for locating JDK 11 on the host
#   If found, outputs the path to stdout and returns with exit code 0
#   If not found, outputs an error message to stderr and returns with exit code 1

java_version() {
    # The one argument is the location of java (either $JAVA_HOME or a potential
    # candidate for JAVA_HOME.
    JAVA="$1"/bin/java
    "$JAVA" -version 2>&1 | grep "\(java\|openjdk\) version" | awk '{ print substr($3, 2, length($3)-2); }'
}

check_if_correct_java_version() {

    # If the string is empty return non-zero code.  We don't want false positives if /bin/java is
    # a valid java version because that will leave JAVA_HOME unset and the init.d scripts will
    # use the default java version, which may not be the correct version.
    if [ -z "$1" ]; then
        return 1
    fi

    # The one argument is the location of java (either $JAVA_HOME or a potential
    # candidate for JAVA_HOME).
    JAVA_VERSION=$(java_version "$1")
    JAVA_MAJOR=$(echo "$JAVA_VERSION" | cut -d'.' -f1)
    if [ "$JAVA_MAJOR" -ge 17 ]; then
        printf "%s" "$1"
        return 0
    else
        return 1
    fi
}

# if Java version of $JAVA_HOME is not correct, then try to find it again below
if ! check_if_correct_java_version "$JAVA_HOME"; then
    java_found=false
    for candidate in \
        /opt/java/openjdk \
        /usr/lib/jvm/java-17-* \
        /usr/lib/jvm/zulu-17 \
        /usr/lib/jvm/default-java \
        /usr/java/default \
        / \
        /usr; do
        if [ -e "$candidate"/bin/java ]; then
            if check_if_correct_java_version "$candidate"; then
                java_found=true
                break
            fi
        fi
    done
fi

# if no appropriate java found
if [ "$java_found" = false ]; then
    echo "Required Java version could not be found, please install JDK 17" 1>&2
    exit 1
fi
